@@ -26,8 +26,9 @@
 
 #ifndef __CPU_H
 #define __CPU_H
-#include <gtk/gtk.h>
 
-gulong read_cpuload();
+#include <glib.h>
+
+gulong read_cpuload(void);
 
 #endif /* ndef __CPU_H */
